ELIB
----

Etcher's personal library for silly utility functions


|OSI|

|license|

|av_master| |av_develop|
|codacy| |coverage|


.. |OSI| image:: https://badges.frapsoft.com/os/v3/open-source-200x33.png?v=103
    :target: https://github.com/ellerbrock/open-source-badges/
.. |license| image:: https://img.shields.io/github/license/132nd-etcher/ELIB.svg
    :target: https://www.gnu.org/licenses/gpl-3.0.en.html
.. |av_master| image:: https://img.shields.io/appveyor/ci/132nd-etcher/elib/master.svg?label=master
    :target: https://ci.appveyor.com/project/132nd-etcher/epab
.. |av_develop| image:: https://img.shields.io/appveyor/ci/132nd-etcher/elib/develop.svg?label=develop
    :target: https://ci.appveyor.com/project/132nd-etcher/epab
.. |codacy| image:: https://img.shields.io/codacy/grade/41cd1e485219427b8ebc56e381550caf.svg
    :target: https://www.codacy.com/app/132nd-etcher/epab
.. |coverage| image:: https://img.shields.io/codacy/coverage/41cd1e485219427b8ebc56e381550caf.svg
    :target: https://www.codacy.com/app/132nd-etcher/epab